@@ -12,6 +12,7 @@ extern void F77_NAME(rhrsbtf)(void *, void *, void *, void *, void *, void *, vo
 extern void F77_NAME(tmklmf)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(tmklmedf)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(omkmf)(void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(omkmnrepf)(void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
 static const R_FortranMethodDef FortranEntries[] = {
     {"rhgsbtf",  (DL_FUNC) &F77_NAME(rhgsbtf),   7},
@@ -19,6 +20,7 @@ static const R_FortranMethodDef FortranEntries[] = {
     {"tmklmf",   (DL_FUNC) &F77_NAME(tmklmf),   10},
     {"tmklmedf", (DL_FUNC) &F77_NAME(tmklmedf), 10},
 	{"omkmf",    (DL_FUNC) &F77_NAME(omkmf),     9},
+	{"omkmnrepf",    (DL_FUNC) &F77_NAME(omkmnrepf),     9},
     {NULL, NULL, 0}
 };
 
